@@ -2,16 +2,24 @@ package Test2::Hub::Subtest;
 use strict;
 use warnings;
 
-our $VERSION = '0.000039';
+our $VERSION = '0.000040';
 
 use base 'Test2::Hub';
-use Test2::Util::HashBase qw/nested bailed_out exit_code manual_skip_all/;
+use Test2::Util::HashBase qw/nested bailed_out exit_code manual_skip_all id/;
 use Test2::Util qw/get_tid/;
 
+my $ID = 1;
+sub init {
+    my $self = shift;
+    $self->SUPER::init(@_);
+    $self->{+ID} ||= join "-", $$, get_tid, $ID++;
+}
+
 sub process {
     my $self = shift;
     my ($e) = @_;
     $e->set_nested($self->nested);
+    $e->set_in_subtest($self->{+ID});
     $self->set_bailed_out($e) if $e->isa('Test2::Event::Bail');
     $self->SUPER::process($e);
 }
